User prompt
when the hero hits cube_fast the cube drop starts before the middle of the screen
User prompt
when a hero hits cube_fast the cube drop starts earlier by 25 percent
User prompt
when a hero hits cube_fast the cube drop starts earlier by 25 percent
User prompt
Fix Bug: 'Uncaught TypeError: Cannot read properties of undefined (reading 'onComplete')' in or related to this line: 'LK.loader.onComplete.add(function () {});' Line Number: 251
User prompt
don't start the game until all the assets are loaded.
User prompt
redo alarm and alarm2 blinks, make them blink three times, with a period of 1 time per second.
User prompt
Between cube_fast and cube_collapse there should be a gap of at least two columns
User prompt
put one cube_collapse in every 22 columns in front of the hero
User prompt
Between cube_fast and cube_collapse there should be a gap of at least two columns
User prompt
cube_fast and cube_collapse must not be in neighboring columns
User prompt
cube_fast and cube_collapse must not be in neighboring columns
User prompt
don't put cube_fast and cube_collapse next to each other.
User prompt
don't put cube_fast and cube_collapse next to each other.
User prompt
cube_fast and cube_collapse should always be placed at the very top of the posts
User prompt
cube_fast and cube_collapse should always be placed on top
User prompt
make the mutual arrangement of cube_fast and cube_collapse more randomized
User prompt
Alarm2 down 300
User prompt
Alarm2 blinks 2 times once per second
User prompt
put one cube_collapse in every 17 columns in front of the hero
User prompt
put one cube_collapse in every 17 columns in front of the hero
User prompt
display Alarm2 in the upper right corner of the screen when the hero hits cube_fast
User prompt
Fix Bug: 'Uncaught ReferenceError: AlarmDisplay is not defined' in or related to this line: 'var alarmDisplay = game.addChild(new AlarmDisplay());' Line Number: 219
User prompt
display Alarm2 in the upper right corner of the screen when the hero hits cube_fast
User prompt
there should be no cube_fast and cube_collapse in the first 100 columns
User prompt
place one cube_fast in every 10 column in front of the player
===================================================================
--- original.js
+++ change.js
@@ -55,22 +55,18 @@
self.cubes = [];
self.addCube = function (isCollapsing) {
var cube;
if (poleCounter >= 100) {
- if (isCollapsing && lastPoleType !== 'CollapsingCube') {
+ if (isCollapsing) {
cube = new CollapsingCube();
- lastPoleType = 'CollapsingCube';
- } else if (poleCounter % 10 === 0 && lastPoleType !== 'FastCube' && poleCounter % 17 !== 0 && poleCounter % 18 !== 0) {
- // Every tenth pole has a fast cube in front of the player, but not if it's also every 17th or 18th pole (collapsing cube) and not if the last pole was a fast cube
+ } else if (poleCounter % 10 === 0 && poleCounter % 17 !== 0 && poleCounter % 27 !== 0) {
+ // Every tenth pole has a fast cube in front of the player, but not if it's also every 17th or 27th pole (to ensure a gap of at least two columns)
cube = new FastCube();
- lastPoleType = 'FastCube';
} else {
cube = new Cube();
- lastPoleType = 'Cube';
}
} else {
cube = new Cube();
- lastPoleType = 'Cube';
}
cube.y = -(self.cubes.length * 100) - (self.cubes.length - 1) * 2;
self.addChild(cube);
self.cubes.push(cube);
girl sitting on Wrecking Ball, cartoon style.. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
construction cranes on the sides of the frame, depth of field blur, cartoon style, black and white. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
"ALARM" text bubble, comic style. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
the surface is gray, concrete with a black square in the center. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
Wrecking Ball with eyes, cartoon style.. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
the surface is red, concrete with a black square in the center.. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
"ALARM" text bubble yellow, comic book style.. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
the surface is yellow, concrete with a black square in the center. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.